@@ -1,5 +1,5 @@
 """
-Filesystem based backend implementation - uses files in directories below a base path.
+Filesystem-based backend implementation - uses files in directories below a base path.
 """
 
 import os
@@ -12,7 +12,7 @@ import tempfile
 
 from ._base import BackendBase, ItemInfo, validate_name
 from .errors import BackendError, BackendAlreadyExists, BackendDoesNotExist, BackendMustNotBeOpen, BackendMustBeOpen
-from .errors import ObjectNotFound
+from .errors import ObjectNotFound, PermissionDenied
 from ..constants import TMP_SUFFIX
 
 
@@ -20,13 +20,13 @@ def get_file_backend(url):
     # file:///absolute/path
     # notes:
     # - we only support **local** fs **absolute** paths.
-    # - there is no such thing as a "relative path" local fs file: url
-    # - the general url syntax is proto://host/path
+    # - there is no such thing as a "relative path" local fs file: URL
+    # - the general URL syntax is proto://host/path
     # - // introduces the host part. it is empty here, meaning localhost / local fs.
     # - the third slash is NOT optional, it is the start of an absolute path as well
     #   as the separator between the host and the path part.
     # - the caller is responsible to give an absolute path.
-    # - windows: see there: https://en.wikipedia.org/wiki/File_URI_scheme
+    # - Windows: see: https://en.wikipedia.org/wiki/File_URI_scheme
     windows_file_regex = r"""
         file://  # only empty host part is supported.
         /  # 3rd slash is separator ONLY, not part of the path.
@@ -49,16 +49,54 @@ class PosixFS(BackendBase):
     # PosixFS implementation supports precreate = True as well as = False.
     precreate_dirs: bool = False
 
-    def __init__(self, path, *, do_fsync=False):
+    def __init__(self, path, *, do_fsync=False, permissions=None):
         self.base_path = Path(path)
         if not self.base_path.is_absolute():
-            raise BackendError("path must be an absolute path")
+            raise BackendError(f"path must be an absolute path: {path}")
         self.opened = False
         self.do_fsync = do_fsync  # False = 26x faster, see #10
+        self.permissions = permissions or {}  # name [str] -> granted_permissions [str]
+
+    def _check_permission(self, name, required_permissions):
+        """
+        Check in the self.permissions mapping if one of the
+        required_permissions is granted for the given name or its parents.
+
+        Permission characters:
+        - l: allow listing object names ("namespace/directory listing")
+        - r: allow reading objects (contents)
+        - w: allow writing NEW objects (must not already exist)
+        - W: allow writing objects (also overwrite existing objects)
+        - D: allow deleting objects
+
+        Move requires "D" (src) and "wW" (dst).
+        Moves are used by the Store for soft-deletion/undeletion, level changes and generic renames.
+
+        If permissions are granted for a directory like "foo", they also apply to objects
+        below that directory, like "foo/bar".
+        """
+        assert set(required_permissions).issubset("lrwWD")
+
+        if not self.permissions:  # If no permissions dict is provided, allow all operations.
+            return
+
+        # Check permissions, starting from full name (full path) going up to the root.
+        path_parts = name.split("/")
+        for i in range(len(path_parts), -1, -1):  # i: LEN .. 0
+            path = "/".join(path_parts[:i])  # path: full path .. root
+            granted_permissions = self.permissions.get(path, "")
+            # Check if any of the required permissions is present.
+            for permission in required_permissions:
+                if permission in granted_permissions:
+                    return  # Permission granted
+
+        # If we get here, none of the required permissions was found
+        raise PermissionDenied(f"One of permissions '{required_permissions}' required for '{name}'")
 
     def create(self):
         if self.opened:
             raise BackendMustNotBeOpen()
+        self._check_permission("", "wW")
         # we accept an already existing empty directory and we also optionally create
         # any missing parent dirs. the latter is important for repository hosters that
         # only offer limited access to their storage (e.g. only via borg/borgstore).
@@ -72,6 +110,7 @@ class PosixFS(BackendBase):
     def destroy(self):
         if self.opened:
             raise BackendMustNotBeOpen()
+        self._check_permission("", "D")
         try:
             shutil.rmtree(os.fspath(self.base_path))
         except FileNotFoundError:
@@ -99,12 +138,17 @@ class PosixFS(BackendBase):
         if not self.opened:
             raise BackendMustBeOpen()
         path = self._validate_join(name)
+        # spamming a store with lots of random empty dirs == DoS, thus require w.
+        self._check_permission(name, "w")
         path.mkdir(parents=True, exist_ok=True)
 
     def rmdir(self, name):
         if not self.opened:
             raise BackendMustBeOpen()
         path = self._validate_join(name)
+        # path.rmdir only removes empty directories, thus no data can be lost.
+        # thus, a granted "w" is already good enough, "D" is also ok.
+        self._check_permission(name, "wD")
         try:
             path.rmdir()
         except FileNotFoundError:
@@ -114,6 +158,8 @@ class PosixFS(BackendBase):
         if not self.opened:
             raise BackendMustBeOpen()
         path = self._validate_join(name)
+        # we do not read object content, so a granted "l" is enough, "r" is also ok.
+        self._check_permission(name, "lr")
         try:
             st = path.stat()
         except FileNotFoundError:
@@ -126,6 +172,7 @@ class PosixFS(BackendBase):
         if not self.opened:
             raise BackendMustBeOpen()
         path = self._validate_join(name)
+        self._check_permission(name, "r")
         try:
             with path.open("rb") as f:
                 if offset > 0:
@@ -147,6 +194,7 @@ class PosixFS(BackendBase):
         if not self.opened:
             raise BackendMustBeOpen()
         path = self._validate_join(name)
+        self._check_permission(name, "W" if path.exists() else "wW")
         tmp_dir = path.parent
         # write to a differently named temp file in same directory first,
         # so the store never sees partially written data.
@@ -171,6 +219,7 @@ class PosixFS(BackendBase):
         if not self.opened:
             raise BackendMustBeOpen()
         path = self._validate_join(name)
+        self._check_permission(name, "D")
         try:
             path.unlink()
         except FileNotFoundError:
@@ -184,6 +233,13 @@ class PosixFS(BackendBase):
             raise BackendMustBeOpen()
         curr_path = self._validate_join(curr_name)
         new_path = self._validate_join(new_name)
+        # random moves could do a lot of harm in the store:
+        # not finding an object anymore is similar to having it deleted.
+        # also, the source object vanishes under its original name, thus we want D for the source.
+        # as the move might replace the destination, we want W or wW for the destination.
+        # move is also used for soft-deletion by the Store, that also hints to using D for the source.
+        self._check_permission(curr_name, "D")
+        self._check_permission(new_name, "W" if new_path.exists() else "wW")
         try:
             # try to do it quickly, not doing the mkdir. fs ops might be slow, esp. on network fs (latency).
             # this will frequently succeed, because the dir is already there.
@@ -202,6 +258,7 @@ class PosixFS(BackendBase):
         if not self.opened:
             raise BackendMustBeOpen()
         path = self._validate_join(name)
+        self._check_permission(name, "l")
         try:
             paths = sorted(path.iterdir())
         except FileNotFoundError:
